# ---------------------------------------------------------
# Project       : SMS tools
#
# Version       : 0.7
#
# First code    : Tobias Gresch <toby@hades.igaia.ch>
#
# Author        : Alexis Domjan <adomjan@horus.ch>
#
# Contributors  : Andreas Trottmann <ftc@aart.ch>
#                 Marc Schaefer <schaefer@alphanet.ch>
#
# YOU USE THIS SOFTWARE AT YOUR OWN RISK, AUTHORS COULD NOT
# BE PURCHASED FOR ANY DAMAGE CAUSED TO YOUR HARDWARE OR
# SOFTWARE
#
# This software is FREE SOFTWARE, that is you can freely
# distribute it as soon as it is with the source code and
# that you DO NOT CHARGE the receiver of any charge
# excepted for copies, etc.
#
# ---------------------------------------------------------
#
# NAME
#	smstools.pm - common code for all smstools
#
# SYNOPSIS
#
#	this module provides the basic procedures to the
# 	SMS tools. Basically to read configuration and 
#	logging facility.
#	It also includes some common variables.
#
# $Id: smstools.pm,v 1.5 2000/05/23 18:28:43 disco Exp $
# ---------------------------------------------------------

package smstools;

require Exporter;

# -- Exported subs and vars
@ISA	= qw( Exporter );
@EXPORT = qw( 	sms_log
	      	sms_init	
		
		$timeout
	      	$version
		%aliases
		%commands
		@froms
		%cfg
		@gateways
	    );


#-- write an entry in the log file. 
sub sms_log {
	($program, $msg) = @_;
        if ($cfg{logfile}) {
                chomp($date = `date`);
                open LOG, ">>$cfg{logfile}";
                print LOG "$date: ${program}[$$]: $msg";
                close LOG;
        } else {
                return 1;
        }
        return 0;
}




#-- Read the configuration file
sub readconfig {
	if (-e $config) {
	        open CFG, $config || die "can't open $config\n";
	        while (<CFG>) {
	                chomp;
	                $line = $_;
	                if ( ($line =~ /^$/) || ($line =~ /^#/) ) {
	                        # nothing to do here
	                } else {
	                        $line =~ /^(.*?)=(.*?)$/;
	                        $cmd   = $1;
	                        $value = $2;
	                        if ($cmd eq "username") {
	                                $cfg{username} = $value;
	                        } elsif ($cmd eq "password") {
	                                $cfg{password} = $value;
	                        } elsif ($cmd eq "logfile") {
	                                $cfg{logfile} = $value;
	                        } elsif ($cmd eq "destination") {
	                                $cfg{destination} = $value;
	                        } elsif ($cmd eq "gateway") {
	                                @gateways = split /,/, $value;
	                        } elsif ($cmd eq "from") {
	                                @froms = split /,/, $value;
	                        } elsif ($cmd eq "alias") {
	                                ($alias,$number) = split /,/, $value;
	                                $aliases{$alias} = $number;
	                        } elsif ($cmd eq "cmd") {
	                                ($word,$command) = split /,/, $value;
	                                $commands{$word} = $command;
	                        }
	                }
	        }
	        close CFG;
	} else {
		die "configuration file ($config) was not found.\n";
	}
}      



# -- Init
sub sms_init {
	&readconfig;
	return 1;
}



# INIT OF MODULE HERE ---
%aliases;
%commands;
@froms;
%cfg;
@gateways;
$timeout = 10.0;
$version = "0.7";
$config = $ENV{'HOME'} . "/.smstoolsrc";

# MODULE OK --
return 1;
